@@ -1,11 +1,11 @@
 package SQL::Dialects::Role;
 
 use strict;
-use warnings;
+use warnings FATAL => "all";
 
 use base qw(Exporter);
 our @EXPORT  = qw(get_config_as_hash);
-our $VERSION = '1.405';
+our $VERSION = '1.407';
 
 sub get_config_as_hash
 {
