@@ -1,14 +1,14 @@
 package SQL::Statement::Operation;
 
 use strict;
-use warnings;
+use warnings FATAL => "all";
 
 use vars qw(@ISA);
-require Carp;
+use Carp ();
 
-require SQL::Statement::Term;
+use SQL::Statement::Term ();
 
-our $VERSION = '1.405';
+our $VERSION = '1.407';
 
 @ISA = qw(SQL::Statement::Term);
 
@@ -89,13 +89,7 @@ sub right { return $_[0]->{RIGHT}; }
 
 sub operate($)
 {
-    Carp::confess(
-                   sprintf(
-                            q{pure virtual function 'operate' called on %s for %s},
-                            ref( $_[0] ) || __PACKAGE__,
-                            $_[0]->{OP}
-                          )
-                 );
+    Carp::confess( sprintf( q{pure virtual function 'operate' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 sub DESTROY
@@ -407,8 +401,7 @@ sub operate($)
     foreach my $r (@right)
     {
         last
-          if $expr |=
-          ( looks_like_number($left) && looks_like_number($r) ) ? $left == $r : $left eq $r;
+          if $expr |= ( looks_like_number($left) && looks_like_number($r) ) ? $left == $r : $left eq $r;
     }
 
     return $expr;
@@ -464,9 +457,9 @@ sub operate($)
     my @right = map { $_->value($eval); } @{ $self->{RIGHT} };
     my $expr  = 0;
 
-    if (    looks_like_number($left)
-         && looks_like_number( $right[0] )
-         && looks_like_number( $right[1] ) )
+    if (   looks_like_number($left)
+        && looks_like_number( $right[0] )
+        && looks_like_number( $right[1] ) )
     {
         $expr = ( $left >= $right[0] ) && ( $left <= $right[1] );
     }
@@ -483,7 +476,7 @@ package SQL::Statement::Operation::Equality;
 use vars qw(@ISA);
 @ISA = qw(SQL::Statement::Operation);
 
-require Carp;
+use Carp ();
 use Scalar::Util qw(looks_like_number);
 
 =pod
@@ -543,24 +536,12 @@ sub operate($)
 
 sub numcmp($)
 {
-    Carp::confess(
-                   sprintf(
-                            q{pure virtual function 'numcmp' called on %s for %s},
-                            ref( $_[0] ) || __PACKAGE__,
-                            $_[0]->{OP}
-                          )
-                 );
+    Carp::confess( sprintf( q{pure virtual function 'numcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 sub strcmp($)
 {
-    Carp::confess(
-                   sprintf(
-                            q{pure virtual function 'strcmp' called on %s for %s},
-                            ref( $_[0] ) || __PACKAGE__,
-                            $_[0]->{OP}
-                          )
-                 );
+    Carp::confess( sprintf( q{pure virtual function 'strcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 package SQL::Statement::Operation::Equal;
@@ -904,13 +885,7 @@ sub right($)
 
 sub regexp($)
 {
-    Carp::confess(
-                   sprintf(
-                            q{pure virtual function 'regexp' called on %s for %s},
-                            ref( $_[0] ) || __PACKAGE__,
-                            $_[0]->{OP}
-                          )
-                 );
+    Carp::confess( sprintf( q{pure virtual function 'regexp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 sub operate($)
@@ -944,7 +919,7 @@ SQL::Statement::Operation::Like - implements the like operation
 
 =head1 DESCRIPTION
 
-SQL::Statement::Operation::Like is used to to the comparisons for the C<LIKE>
+SQL::Statement::Operation::Like is used to the comparisons for the C<LIKE>
 operation.
 
 =head1 INHERITANCE
@@ -989,7 +964,7 @@ SQL::Statement::Operation::Clike - implements the clike operation
 
 =head1 DESCRIPTION
 
-SQL::Statement::Operation::Clike is used to to the comparisons for the C<CLIKE>
+SQL::Statement::Operation::Clike is used to the comparisons for the C<CLIKE>
 operation.
 
 =head1 INHERITANCE
@@ -1034,7 +1009,7 @@ SQL::Statement::Operation::RLike - implements the rlike operation
 
 =head1 DESCRIPTION
 
-SQL::Statement::Operation::RLike is used to to the comparisons for the C<RLIKE>
+SQL::Statement::Operation::RLike is used to the comparisons for the C<RLIKE>
 operation.
 
 =head1 INHERITANCE
