@@ -3,19 +3,19 @@ package SQL::Statement::RAM;
 ############################
 
 use strict;
-use warnings;
+use warnings FATAL => "all";
 
 use vars qw($VERSION);
-$VERSION = '1.405';
+$VERSION = '1.407';
 
 ####################################
 package SQL::Statement::RAM::Table;
 ####################################
 
 use strict;
-use warnings;
+use warnings FATAL => "all";
 
-require SQL::Eval;
+use SQL::Eval ();
 
 use vars qw(@ISA);
 @ISA = qw(SQL::Eval::Table);
@@ -26,15 +26,15 @@ sub new
 {
     my ( $class, $tname, $col_names, $data_tbl ) = @_;
     my %table = (
-                  NAME         => $tname,
-                  index        => 0,
-                  records      => $data_tbl,
-                  col_names    => $col_names,
-                  capabilities => {
-                                    inplace_update => 1,
-                                    inplace_delete => 1,
-                                  },
-                );
+        NAME         => $tname,
+        index        => 0,
+        records      => $data_tbl,
+        col_names    => $col_names,
+        capabilities => {
+            inplace_update => 1,
+            inplace_delete => 1,
+        },
+    );
     my $self = $class->SUPER::new( \%table );
 }
 
