@@ -1,9 +1,9 @@
 package SQL::Statement::Term;
 
 use strict;
-use warnings;
+use warnings FATAL => "all";
 
-our $VERSION = '1.405';
+our $VERSION = '1.407';
 
 use Scalar::Util qw(weaken);
 use Carp ();
@@ -66,8 +66,7 @@ sub DESTROY
 
 sub value($)
 {
-    Carp::confess(
-              sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) );
+    Carp::confess( sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) );
 }
 
 package SQL::Statement::ConstantTerm;
